#ifndef _CHRONOPTICS_TOF_CSF_WRITER_HPP_
#define _CHRONOPTICS_TOF_CSF_WRITER_HPP_

#include <chronoptics/tof/csf_writer.h>

#include <chronoptics/tof/camera_config.hpp>
#include <chronoptics/tof/calibration.hpp>
#include <chronoptics/tof/camera.hpp>
#include <chronoptics/tof/data.hpp>
#include <chronoptics/tof/csf_reader.hpp>
#include <chronoptics/tof/gige_interface.hpp>
#include <chronoptics/tof/usb_interface.hpp>

namespace chronoptics {
namespace tof {

/** The csf writer class takes care of writing depth frames to disk.  The class
 * has to be created from either a Camera or csf reader, because it needs
 * information about the camera that was used to record the depth frames. 
 * Therefore you should only write depth frames coming from one camera into the
 * same writer

*/
class CsfWriter : public detail::Base<tof_csf_writer, tof_csf_writer_delete> {
 public:
  /** Construct from pointer */
  CsfWriter(tof_csf_writer_t ptr = nullptr) {
    this->ptr_ = ptr;
  }

  /** Construct csf writer from calibration and configuration
   * @param file_location Path to where the csf file should be created
   * @param camera_config Camera configuration
   * @param calibration Calibration
   * @param serial Serial number of camera
   */
  CsfWriter(StringView file_location, const CameraConfig &camera_config, const Calibration &calibration, StringView serial) {
    this->ptr_ = tof_csf_writer_new(file_location, *reinterpret_cast<const tof_camera_config_t*>(&camera_config), *reinterpret_cast<const tof_calibration_t*>(&calibration), serial, TOF_ERROR_HANDLER{});
  }

  /** Construct the csf writer from a camera
   * @param file_location Path to where the csf file should be created
   * @param camera The camera to get the camera config and calibration file from
   */
  CsfWriter(StringView file_location, Camera &camera) {
    this->ptr_ = tof_csf_writer_new_from_camera(file_location, *reinterpret_cast<tof_camera_t*>(&camera), TOF_ERROR_HANDLER{});
  }

  /** Write frame to csf file
   * @param frame A data frame
   */
  void write_frame(const Data &frame) {
    return tof_csf_writer_write_frame(this->ptr_, *reinterpret_cast<const tof_data_t*>(&frame), TOF_ERROR_HANDLER{});
  }

};

/** Create csf writer from csf reader
 * @param file_location Path to where the csf file should be created
 * @param reader A csf reader
 * @return csf writer
 */
inline CsfWriter create_csf_writer_reader(StringView file_location, const CsfReader &reader) {
  CsfWriter new_csf_writer(static_cast<tof_csf_writer_t>(nullptr));
  auto ptr = reinterpret_cast<tof_csf_writer_t*>(&new_csf_writer);
  *ptr = tof_create_csf_writer_reader(file_location, *reinterpret_cast<const tof_csf_reader_t*>(&reader), TOF_ERROR_HANDLER{});
  return new_csf_writer;
}

/** Create csf writer from camera
 * @param file_location Path to where the csf file should be created
 * @param camera A camera
 * @return csf writer
 */
inline CsfWriter create_csf_writer_camera(StringView file_location, const Camera &camera) {
  CsfWriter new_csf_writer(static_cast<tof_csf_writer_t>(nullptr));
  auto ptr = reinterpret_cast<tof_csf_writer_t*>(&new_csf_writer);
  *ptr = tof_create_csf_writer_camera(file_location, *reinterpret_cast<const tof_camera_t*>(&camera), TOF_ERROR_HANDLER{});
  return new_csf_writer;
}

/** Create csf writer from the GigE interface
 * @param file_location Path to where the csf file should be created
 * @param gige_interface A GigE interface
 * @return csf writer
 */
inline CsfWriter create_csf_writer_gige_interface(StringView file_location, const GigeInterface &gige_interface) {
  CsfWriter new_csf_writer(static_cast<tof_csf_writer_t>(nullptr));
  auto ptr = reinterpret_cast<tof_csf_writer_t*>(&new_csf_writer);
  *ptr = tof_create_csf_writer_gige_interface(file_location, *reinterpret_cast<const tof_gige_interface_t*>(&gige_interface), TOF_ERROR_HANDLER{});
  return new_csf_writer;
}

/** Create csf writer from the USB interface
 * @param file_location Path to where the csf file should be created
 * @param usb_interface A USB interface
 * @return csf writer
 */
inline CsfWriter create_csf_writer_usb_interface(StringView file_location, const UsbInterface &usb_interface) {
  CsfWriter new_csf_writer(static_cast<tof_csf_writer_t>(nullptr));
  auto ptr = reinterpret_cast<tof_csf_writer_t*>(&new_csf_writer);
  *ptr = tof_create_csf_writer_usb_interface(file_location, *reinterpret_cast<const tof_usb_interface_t*>(&usb_interface), TOF_ERROR_HANDLER{});
  return new_csf_writer;
}

} // tof
} // chronoptics

#endif
