import ctypes
import os
import platform

def find_library():
    from ctypes.util import find_library

    lib_name = find_library("tof")
    if not lib_name:
        env_var = "TOF_DIR"
        if env_var not in os.environ:
            raise RuntimeError("Library tof not found")
        
        lib_dir = os.environ[env_var]

        os_name = platform.system()
        if os_name == "Linux":
            lib_name = "libtof.so"
        elif os_name == "Darwin":
            lib_name = "libtof.dylib"
        else:
            # Assume windows
            lib_name = "tof.dll"

        lib_name = os.path.join(lib_dir, lib_name)

    return ctypes.CDLL(lib_name)


def get_error():
    return ctypes.byref(ctypes.c_void_p())


def check_error(result, func, args):
    error = args[len(args) - 1]._obj

    if error:
        msg = lib.tof_error_message(error)
        lib.tof_error_delete(error)
        raise RuntimeError(msg)

    return args


def setup_library(lib):
    lib.tof_error_delete.restype = None
    lib.tof_error_delete.argtypes = [ctypes.c_void_p]

    lib.tof_error_message.restype = ctypes.c_char_p
    lib.tof_error_message.argtypes = [ctypes.c_void_p]

    lib.tof_stream_delete.restype = None
    lib.tof_stream_delete.argtypes = [ctypes.c_void_p]

    lib.tof_stream_frame_type.restype = ctypes.c_int
    lib.tof_stream_frame_type.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_stream_frame_type.errcheck = check_error

    lib.tof_stream_frame_id.restype = ctypes.c_uint32
    lib.tof_stream_frame_id.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_stream_frame_id.errcheck = check_error

    lib.tof_stream_modulation_frequency.restype = ctypes.c_float
    lib.tof_stream_modulation_frequency.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_stream_modulation_frequency.errcheck = check_error

    lib.tof_stream_integration_time.restype = ctypes.c_uint32
    lib.tof_stream_integration_time.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_stream_integration_time.errcheck = check_error

    lib.tof_stream_process.restype = ctypes.c_uint32
    lib.tof_stream_process.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_stream_process.errcheck = check_error

    lib.tof_frame_type_to_string.restype = ctypes.c_char_p
    lib.tof_frame_type_to_string.argtypes = [ctypes.c_int, ctypes.c_void_p]
    lib.tof_frame_type_to_string.errcheck = check_error

    lib.tof_data_delete.restype = None
    lib.tof_data_delete.argtypes = [ctypes.c_void_p]

    lib.tof_data_data.restype = ctypes.c_void_p
    lib.tof_data_data.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_data_data.errcheck = check_error

    lib.tof_data_size.restype = ctypes.c_size_t
    lib.tof_data_size.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_data_size.errcheck = check_error

    lib.tof_data_get_user_data.restype = ctypes.c_uint64
    lib.tof_data_get_user_data.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_data_get_user_data.errcheck = check_error

    lib.tof_data_set_user_data.restype = None
    lib.tof_data_set_user_data.argtypes = [ctypes.c_void_p, ctypes.c_uint64, ctypes.c_void_p]
    lib.tof_data_set_user_data.errcheck = check_error

    lib.tof_data_mat_type.restype = ctypes.c_int
    lib.tof_data_mat_type.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_data_mat_type.errcheck = check_error

    lib.tof_data_rows.restype = ctypes.c_int32
    lib.tof_data_rows.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_data_rows.errcheck = check_error

    lib.tof_data_cols.restype = ctypes.c_int32
    lib.tof_data_cols.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_data_cols.errcheck = check_error

    lib.tof_data_frame_count.restype = ctypes.c_uint16
    lib.tof_data_frame_count.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_data_frame_count.errcheck = check_error

    lib.tof_data_frame_type.restype = ctypes.c_int
    lib.tof_data_frame_type.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_data_frame_type.errcheck = check_error

    lib.tof_data_frame_id.restype = ctypes.c_uint32
    lib.tof_data_frame_id.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_data_frame_id.errcheck = check_error

    lib.tof_data_modulation_frequency.restype = ctypes.c_float
    lib.tof_data_modulation_frequency.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_data_modulation_frequency.errcheck = check_error

    lib.tof_data_integration_time.restype = ctypes.c_uint32
    lib.tof_data_integration_time.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_data_integration_time.errcheck = check_error

    lib.tof_data_process.restype = ctypes.c_uint32
    lib.tof_data_process.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_data_process.errcheck = check_error

    lib.tof_data_scale.restype = ctypes.c_float
    lib.tof_data_scale.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_data_scale.errcheck = check_error

    lib.tof_data_addition.restype = ctypes.c_float
    lib.tof_data_addition.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_data_addition.errcheck = check_error

    lib.tof_data_temperatures.restype = ctypes.c_size_t
    lib.tof_data_temperatures.argtypes = [ctypes.c_void_p, ctypes.POINTER(ctypes.c_float), ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_data_temperatures.errcheck = check_error

    lib.tof_data_sync_count.restype = ctypes.c_uint8
    lib.tof_data_sync_count.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_data_sync_count.errcheck = check_error

    lib.tof_data_user_allocated.restype = ctypes.c_bool
    lib.tof_data_user_allocated.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_data_user_allocated.errcheck = check_error

    lib.tof_data_user_pointer.restype = ctypes.c_void_p
    lib.tof_data_user_pointer.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_data_user_pointer.errcheck = check_error

    lib.tof_csf_reader_delete.restype = None
    lib.tof_csf_reader_delete.argtypes = [ctypes.c_void_p]

    lib.tof_csf_reader_new.restype = ctypes.c_void_p
    lib.tof_csf_reader_new.argtypes = [ctypes.c_char_p, ctypes.c_void_p]
    lib.tof_csf_reader_new.errcheck = check_error

    lib.tof_csf_reader_read_frame.restype = ctypes.c_void_p
    lib.tof_csf_reader_read_frame.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_csf_reader_read_frame.errcheck = check_error

    lib.tof_csf_reader_number_of_frames.restype = ctypes.c_size_t
    lib.tof_csf_reader_number_of_frames.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_csf_reader_number_of_frames.errcheck = check_error

    lib.tof_csf_reader_get_header.restype = ctypes.c_void_p
    lib.tof_csf_reader_get_header.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_csf_reader_get_header.errcheck = check_error

    lib.tof_csf_reader_next_stream.restype = ctypes.c_void_p
    lib.tof_csf_reader_next_stream.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_csf_reader_next_stream.errcheck = check_error

    lib.tof_csf_reader_next_frame_size.restype = ctypes.c_size_t
    lib.tof_csf_reader_next_frame_size.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_csf_reader_next_frame_size.errcheck = check_error

    lib.tof_csf_reader_frame_index.restype = ctypes.c_size_t
    lib.tof_csf_reader_frame_index.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_csf_reader_frame_index.errcheck = check_error

    lib.tof_csf_reader_go_to_frame.restype = None
    lib.tof_csf_reader_go_to_frame.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_csf_reader_go_to_frame.errcheck = check_error

    lib.tof_csf_reader_streams.restype = ctypes.c_size_t
    lib.tof_csf_reader_streams.argtypes = [ctypes.c_void_p, ctypes.POINTER(ctypes.c_void_p), ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_csf_reader_streams.errcheck = check_error

    lib.tof_csf_reader_stream_count.restype = ctypes.c_size_t
    lib.tof_csf_reader_stream_count.argtypes = [ctypes.c_void_p, ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_csf_reader_stream_count.errcheck = check_error

    lib.tof_csf_reader_go_to_stream.restype = None
    lib.tof_csf_reader_go_to_stream.argtypes = [ctypes.c_void_p, ctypes.c_void_p, ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_csf_reader_go_to_stream.errcheck = check_error

    lib.tof_csf_reader_get_calibration.restype = ctypes.c_void_p
    lib.tof_csf_reader_get_calibration.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_csf_reader_get_calibration.errcheck = check_error

    lib.tof_csf_reader_get_camera_config.restype = ctypes.c_void_p
    lib.tof_csf_reader_get_camera_config.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_csf_reader_get_camera_config.errcheck = check_error

    lib.tof_csf_writer_delete.restype = None
    lib.tof_csf_writer_delete.argtypes = [ctypes.c_void_p]

    lib.tof_csf_writer_new.restype = ctypes.c_void_p
    lib.tof_csf_writer_new.argtypes = [ctypes.c_char_p, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_char_p, ctypes.c_void_p]
    lib.tof_csf_writer_new.errcheck = check_error

    lib.tof_csf_writer_new_from_camera.restype = ctypes.c_void_p
    lib.tof_csf_writer_new_from_camera.argtypes = [ctypes.c_char_p, ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_csf_writer_new_from_camera.errcheck = check_error

    lib.tof_csf_writer_write_frame.restype = None
    lib.tof_csf_writer_write_frame.argtypes = [ctypes.c_void_p, ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_csf_writer_write_frame.errcheck = check_error

    lib.tof_create_csf_writer_reader.restype = ctypes.c_void_p
    lib.tof_create_csf_writer_reader.argtypes = [ctypes.c_char_p, ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_create_csf_writer_reader.errcheck = check_error

    lib.tof_create_csf_writer_camera.restype = ctypes.c_void_p
    lib.tof_create_csf_writer_camera.argtypes = [ctypes.c_char_p, ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_create_csf_writer_camera.errcheck = check_error

    lib.tof_create_csf_writer_gige_interface.restype = ctypes.c_void_p
    lib.tof_create_csf_writer_gige_interface.argtypes = [ctypes.c_char_p, ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_create_csf_writer_gige_interface.errcheck = check_error

    lib.tof_create_csf_writer_usb_interface.restype = ctypes.c_void_p
    lib.tof_create_csf_writer_usb_interface.argtypes = [ctypes.c_char_p, ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_create_csf_writer_usb_interface.errcheck = check_error

    lib.tof_user_config_delete.restype = None
    lib.tof_user_config_delete.argtypes = [ctypes.c_void_p]

    lib.tof_user_config_new_default.restype = ctypes.c_void_p
    lib.tof_user_config_new_default.argtypes = [ctypes.c_void_p]
    lib.tof_user_config_new_default.errcheck = check_error

    lib.tof_user_config_to_camera_config.restype = ctypes.c_void_p
    lib.tof_user_config_to_camera_config.argtypes = [ctypes.c_void_p, ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_user_config_to_camera_config.errcheck = check_error

    lib.tof_user_config_get_environment.restype = ctypes.c_int
    lib.tof_user_config_get_environment.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_user_config_get_environment.errcheck = check_error

    lib.tof_user_config_set_environment.restype = None
    lib.tof_user_config_set_environment.argtypes = [ctypes.c_void_p, ctypes.c_int, ctypes.c_void_p]
    lib.tof_user_config_set_environment.errcheck = check_error

    lib.tof_user_config_get_max_distance.restype = ctypes.c_float
    lib.tof_user_config_get_max_distance.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_user_config_get_max_distance.errcheck = check_error

    lib.tof_user_config_set_max_distance.restype = None
    lib.tof_user_config_set_max_distance.argtypes = [ctypes.c_void_p, ctypes.c_float, ctypes.c_void_p]
    lib.tof_user_config_set_max_distance.errcheck = check_error

    lib.tof_user_config_get_fps.restype = ctypes.c_float
    lib.tof_user_config_get_fps.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_user_config_get_fps.errcheck = check_error

    lib.tof_user_config_set_fps.restype = None
    lib.tof_user_config_set_fps.argtypes = [ctypes.c_void_p, ctypes.c_float, ctypes.c_void_p]
    lib.tof_user_config_set_fps.errcheck = check_error

    lib.tof_user_config_get_lens_flare.restype = ctypes.c_bool
    lib.tof_user_config_get_lens_flare.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_user_config_get_lens_flare.errcheck = check_error

    lib.tof_user_config_set_lens_flare.restype = None
    lib.tof_user_config_set_lens_flare.argtypes = [ctypes.c_void_p, ctypes.c_bool, ctypes.c_void_p]
    lib.tof_user_config_set_lens_flare.errcheck = check_error

    lib.tof_user_config_get_translucent.restype = ctypes.c_bool
    lib.tof_user_config_get_translucent.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_user_config_get_translucent.errcheck = check_error

    lib.tof_user_config_set_translucent.restype = None
    lib.tof_user_config_set_translucent.argtypes = [ctypes.c_void_p, ctypes.c_bool, ctypes.c_void_p]
    lib.tof_user_config_set_translucent.errcheck = check_error

    lib.tof_user_config_get_hdr.restype = ctypes.c_bool
    lib.tof_user_config_get_hdr.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_user_config_get_hdr.errcheck = check_error

    lib.tof_user_config_set_hdr.restype = None
    lib.tof_user_config_set_hdr.argtypes = [ctypes.c_void_p, ctypes.c_bool, ctypes.c_void_p]
    lib.tof_user_config_set_hdr.errcheck = check_error

    lib.tof_user_config_get_integration_time.restype = ctypes.c_int
    lib.tof_user_config_get_integration_time.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_user_config_get_integration_time.errcheck = check_error

    lib.tof_user_config_set_integration_time.restype = None
    lib.tof_user_config_set_integration_time.argtypes = [ctypes.c_void_p, ctypes.c_int, ctypes.c_void_p]
    lib.tof_user_config_set_integration_time.errcheck = check_error

    lib.tof_user_config_get_strategy.restype = ctypes.c_int
    lib.tof_user_config_get_strategy.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_user_config_get_strategy.errcheck = check_error

    lib.tof_user_config_set_strategy.restype = None
    lib.tof_user_config_set_strategy.argtypes = [ctypes.c_void_p, ctypes.c_int, ctypes.c_void_p]
    lib.tof_user_config_set_strategy.errcheck = check_error

    lib.tof_user_config_get_channel.restype = ctypes.c_int32
    lib.tof_user_config_get_channel.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_user_config_get_channel.errcheck = check_error

    lib.tof_user_config_set_channel.restype = None
    lib.tof_user_config_set_channel.argtypes = [ctypes.c_void_p, ctypes.c_int32, ctypes.c_void_p]
    lib.tof_user_config_set_channel.errcheck = check_error

    lib.tof_hdr_possible.restype = ctypes.c_bool
    lib.tof_hdr_possible.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_hdr_possible.errcheck = check_error

    lib.tof_phase_unwrap_possible.restype = ctypes.c_bool
    lib.tof_phase_unwrap_possible.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_phase_unwrap_possible.errcheck = check_error

    lib.tof_processing_config_delete.restype = None
    lib.tof_processing_config_delete.argtypes = [ctypes.c_void_p]

    lib.tof_processing_config_new_default.restype = ctypes.c_void_p
    lib.tof_processing_config_new_default.argtypes = [ctypes.c_void_p]
    lib.tof_processing_config_new_default.errcheck = check_error

    lib.tof_processing_config_new_from_disk.restype = ctypes.c_void_p
    lib.tof_processing_config_new_from_disk.argtypes = [ctypes.c_char_p, ctypes.c_void_p]
    lib.tof_processing_config_new_from_disk.errcheck = check_error

    lib.tof_processing_config_write.restype = None
    lib.tof_processing_config_write.argtypes = [ctypes.c_void_p, ctypes.c_char_p, ctypes.c_void_p]
    lib.tof_processing_config_write.errcheck = check_error

    lib.tof_processing_config_get_gpu.restype = ctypes.c_bool
    lib.tof_processing_config_get_gpu.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_gpu.errcheck = check_error

    lib.tof_processing_config_set_gpu.restype = None
    lib.tof_processing_config_set_gpu.argtypes = [ctypes.c_void_p, ctypes.c_bool, ctypes.c_void_p]
    lib.tof_processing_config_set_gpu.errcheck = check_error

    lib.tof_processing_config_get_calibration_enabled.restype = ctypes.c_bool
    lib.tof_processing_config_get_calibration_enabled.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_calibration_enabled.errcheck = check_error

    lib.tof_processing_config_set_calibration_enabled.restype = None
    lib.tof_processing_config_set_calibration_enabled.argtypes = [ctypes.c_void_p, ctypes.c_bool, ctypes.c_void_p]
    lib.tof_processing_config_set_calibration_enabled.errcheck = check_error

    lib.tof_processing_config_get_phase_unwrapping_enabled.restype = ctypes.c_bool
    lib.tof_processing_config_get_phase_unwrapping_enabled.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_phase_unwrapping_enabled.errcheck = check_error

    lib.tof_processing_config_set_phase_unwrapping_enabled.restype = None
    lib.tof_processing_config_set_phase_unwrapping_enabled.argtypes = [ctypes.c_void_p, ctypes.c_bool, ctypes.c_void_p]
    lib.tof_processing_config_set_phase_unwrapping_enabled.errcheck = check_error

    lib.tof_processing_config_get_phase_unwrapping_max_offset.restype = ctypes.c_double
    lib.tof_processing_config_get_phase_unwrapping_max_offset.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_phase_unwrapping_max_offset.errcheck = check_error

    lib.tof_processing_config_set_phase_unwrapping_max_offset.restype = None
    lib.tof_processing_config_set_phase_unwrapping_max_offset.argtypes = [ctypes.c_void_p, ctypes.c_double, ctypes.c_void_p]
    lib.tof_processing_config_set_phase_unwrapping_max_offset.errcheck = check_error

    lib.tof_processing_config_get_mpi_detect_enabled.restype = ctypes.c_bool
    lib.tof_processing_config_get_mpi_detect_enabled.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_mpi_detect_enabled.errcheck = check_error

    lib.tof_processing_config_set_mpi_detect_enabled.restype = None
    lib.tof_processing_config_set_mpi_detect_enabled.argtypes = [ctypes.c_void_p, ctypes.c_bool, ctypes.c_void_p]
    lib.tof_processing_config_set_mpi_detect_enabled.errcheck = check_error

    lib.tof_processing_config_get_mpi_detect_aratio.restype = ctypes.c_float
    lib.tof_processing_config_get_mpi_detect_aratio.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_mpi_detect_aratio.errcheck = check_error

    lib.tof_processing_config_set_mpi_detect_aratio.restype = None
    lib.tof_processing_config_set_mpi_detect_aratio.argtypes = [ctypes.c_void_p, ctypes.c_float, ctypes.c_void_p]
    lib.tof_processing_config_set_mpi_detect_aratio.errcheck = check_error

    lib.tof_processing_config_get_mpi_detect_phi_diff.restype = ctypes.c_float
    lib.tof_processing_config_get_mpi_detect_phi_diff.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_mpi_detect_phi_diff.errcheck = check_error

    lib.tof_processing_config_set_mpi_detect_phi_diff.restype = None
    lib.tof_processing_config_set_mpi_detect_phi_diff.argtypes = [ctypes.c_void_p, ctypes.c_float, ctypes.c_void_p]
    lib.tof_processing_config_set_mpi_detect_phi_diff.errcheck = check_error

    lib.tof_processing_config_get_mixed_pixel_enabled.restype = ctypes.c_bool
    lib.tof_processing_config_get_mixed_pixel_enabled.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_mixed_pixel_enabled.errcheck = check_error

    lib.tof_processing_config_set_mixed_pixel_enabled.restype = None
    lib.tof_processing_config_set_mixed_pixel_enabled.argtypes = [ctypes.c_void_p, ctypes.c_bool, ctypes.c_void_p]
    lib.tof_processing_config_set_mixed_pixel_enabled.errcheck = check_error

    lib.tof_processing_config_get_mixed_pixel_lut_file.restype = ctypes.c_char_p
    lib.tof_processing_config_get_mixed_pixel_lut_file.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_mixed_pixel_lut_file.errcheck = check_error

    lib.tof_processing_config_set_mixed_pixel_lut_file.restype = None
    lib.tof_processing_config_set_mixed_pixel_lut_file.argtypes = [ctypes.c_void_p, ctypes.c_char_p, ctypes.c_void_p]
    lib.tof_processing_config_set_mixed_pixel_lut_file.errcheck = check_error

    lib.tof_processing_config_get_mixed_pixel_amp_min.restype = ctypes.c_double
    lib.tof_processing_config_get_mixed_pixel_amp_min.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_mixed_pixel_amp_min.errcheck = check_error

    lib.tof_processing_config_set_mixed_pixel_amp_min.restype = None
    lib.tof_processing_config_set_mixed_pixel_amp_min.argtypes = [ctypes.c_void_p, ctypes.c_double, ctypes.c_void_p]
    lib.tof_processing_config_set_mixed_pixel_amp_min.errcheck = check_error

    lib.tof_processing_config_get_mixed_pixel_sort_mode.restype = ctypes.c_int
    lib.tof_processing_config_get_mixed_pixel_sort_mode.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_mixed_pixel_sort_mode.errcheck = check_error

    lib.tof_processing_config_set_mixed_pixel_sort_mode.restype = None
    lib.tof_processing_config_set_mixed_pixel_sort_mode.argtypes = [ctypes.c_void_p, ctypes.c_int, ctypes.c_void_p]
    lib.tof_processing_config_set_mixed_pixel_sort_mode.errcheck = check_error

    lib.tof_processing_config_get_mixed_pixel_aratio.restype = ctypes.c_double
    lib.tof_processing_config_get_mixed_pixel_aratio.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_mixed_pixel_aratio.errcheck = check_error

    lib.tof_processing_config_set_mixed_pixel_aratio.restype = None
    lib.tof_processing_config_set_mixed_pixel_aratio.argtypes = [ctypes.c_void_p, ctypes.c_double, ctypes.c_void_p]
    lib.tof_processing_config_set_mixed_pixel_aratio.errcheck = check_error

    lib.tof_processing_config_get_mixed_pixel_phi_diff.restype = ctypes.c_double
    lib.tof_processing_config_get_mixed_pixel_phi_diff.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_mixed_pixel_phi_diff.errcheck = check_error

    lib.tof_processing_config_set_mixed_pixel_phi_diff.restype = None
    lib.tof_processing_config_set_mixed_pixel_phi_diff.argtypes = [ctypes.c_void_p, ctypes.c_double, ctypes.c_void_p]
    lib.tof_processing_config_set_mixed_pixel_phi_diff.errcheck = check_error

    lib.tof_processing_config_get_mixed_pixel_aggressor_threshold.restype = ctypes.c_double
    lib.tof_processing_config_get_mixed_pixel_aggressor_threshold.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_mixed_pixel_aggressor_threshold.errcheck = check_error

    lib.tof_processing_config_set_mixed_pixel_aggressor_threshold.restype = None
    lib.tof_processing_config_set_mixed_pixel_aggressor_threshold.argtypes = [ctypes.c_void_p, ctypes.c_double, ctypes.c_void_p]
    lib.tof_processing_config_set_mixed_pixel_aggressor_threshold.errcheck = check_error

    lib.tof_processing_config_get_mixed_pixel_min_aggressor_size.restype = ctypes.c_int32
    lib.tof_processing_config_get_mixed_pixel_min_aggressor_size.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_mixed_pixel_min_aggressor_size.errcheck = check_error

    lib.tof_processing_config_set_mixed_pixel_min_aggressor_size.restype = None
    lib.tof_processing_config_set_mixed_pixel_min_aggressor_size.argtypes = [ctypes.c_void_p, ctypes.c_int32, ctypes.c_void_p]
    lib.tof_processing_config_set_mixed_pixel_min_aggressor_size.errcheck = check_error

    lib.tof_processing_config_get_mixed_pixel_max_error_3f.restype = ctypes.c_double
    lib.tof_processing_config_get_mixed_pixel_max_error_3f.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_mixed_pixel_max_error_3f.errcheck = check_error

    lib.tof_processing_config_set_mixed_pixel_max_error_3f.restype = None
    lib.tof_processing_config_set_mixed_pixel_max_error_3f.argtypes = [ctypes.c_void_p, ctypes.c_double, ctypes.c_void_p]
    lib.tof_processing_config_set_mixed_pixel_max_error_3f.errcheck = check_error

    lib.tof_processing_config_get_mixed_pixel_adaptive_amp_max.restype = ctypes.c_double
    lib.tof_processing_config_get_mixed_pixel_adaptive_amp_max.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_mixed_pixel_adaptive_amp_max.errcheck = check_error

    lib.tof_processing_config_set_mixed_pixel_adaptive_amp_max.restype = None
    lib.tof_processing_config_set_mixed_pixel_adaptive_amp_max.argtypes = [ctypes.c_void_p, ctypes.c_double, ctypes.c_void_p]
    lib.tof_processing_config_set_mixed_pixel_adaptive_amp_max.errcheck = check_error

    lib.tof_processing_config_get_mixed_pixel_adaptive_amp_min.restype = ctypes.c_double
    lib.tof_processing_config_get_mixed_pixel_adaptive_amp_min.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_mixed_pixel_adaptive_amp_min.errcheck = check_error

    lib.tof_processing_config_set_mixed_pixel_adaptive_amp_min.restype = None
    lib.tof_processing_config_set_mixed_pixel_adaptive_amp_min.argtypes = [ctypes.c_void_p, ctypes.c_double, ctypes.c_void_p]
    lib.tof_processing_config_set_mixed_pixel_adaptive_amp_min.errcheck = check_error

    lib.tof_processing_config_get_mixed_pixel_aratio_min.restype = ctypes.c_double
    lib.tof_processing_config_get_mixed_pixel_aratio_min.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_mixed_pixel_aratio_min.errcheck = check_error

    lib.tof_processing_config_set_mixed_pixel_aratio_min.restype = None
    lib.tof_processing_config_set_mixed_pixel_aratio_min.argtypes = [ctypes.c_void_p, ctypes.c_double, ctypes.c_void_p]
    lib.tof_processing_config_set_mixed_pixel_aratio_min.errcheck = check_error

    lib.tof_processing_config_get_mixed_pixel_aggressor_phi_offset.restype = ctypes.c_double
    lib.tof_processing_config_get_mixed_pixel_aggressor_phi_offset.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_mixed_pixel_aggressor_phi_offset.errcheck = check_error

    lib.tof_processing_config_set_mixed_pixel_aggressor_phi_offset.restype = None
    lib.tof_processing_config_set_mixed_pixel_aggressor_phi_offset.argtypes = [ctypes.c_void_p, ctypes.c_double, ctypes.c_void_p]
    lib.tof_processing_config_set_mixed_pixel_aggressor_phi_offset.errcheck = check_error

    lib.tof_processing_config_get_hdr_enabled.restype = ctypes.c_bool
    lib.tof_processing_config_get_hdr_enabled.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_hdr_enabled.errcheck = check_error

    lib.tof_processing_config_set_hdr_enabled.restype = None
    lib.tof_processing_config_set_hdr_enabled.argtypes = [ctypes.c_void_p, ctypes.c_bool, ctypes.c_void_p]
    lib.tof_processing_config_set_hdr_enabled.errcheck = check_error

    lib.tof_processing_config_get_average_enabled.restype = ctypes.c_bool
    lib.tof_processing_config_get_average_enabled.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_average_enabled.errcheck = check_error

    lib.tof_processing_config_set_average_enabled.restype = None
    lib.tof_processing_config_set_average_enabled.argtypes = [ctypes.c_void_p, ctypes.c_bool, ctypes.c_void_p]
    lib.tof_processing_config_set_average_enabled.errcheck = check_error

    lib.tof_processing_config_get_average_nframes.restype = ctypes.c_size_t
    lib.tof_processing_config_get_average_nframes.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_average_nframes.errcheck = check_error

    lib.tof_processing_config_set_average_nframes.restype = None
    lib.tof_processing_config_set_average_nframes.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_processing_config_set_average_nframes.errcheck = check_error

    lib.tof_processing_config_get_temporal_enabled.restype = ctypes.c_bool
    lib.tof_processing_config_get_temporal_enabled.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_temporal_enabled.errcheck = check_error

    lib.tof_processing_config_set_temporal_enabled.restype = None
    lib.tof_processing_config_set_temporal_enabled.argtypes = [ctypes.c_void_p, ctypes.c_bool, ctypes.c_void_p]
    lib.tof_processing_config_set_temporal_enabled.errcheck = check_error

    lib.tof_processing_config_get_temporal_sigma.restype = ctypes.c_double
    lib.tof_processing_config_get_temporal_sigma.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_temporal_sigma.errcheck = check_error

    lib.tof_processing_config_set_temporal_sigma.restype = None
    lib.tof_processing_config_set_temporal_sigma.argtypes = [ctypes.c_void_p, ctypes.c_double, ctypes.c_void_p]
    lib.tof_processing_config_set_temporal_sigma.errcheck = check_error

    lib.tof_processing_config_get_temporal_nframes.restype = ctypes.c_size_t
    lib.tof_processing_config_get_temporal_nframes.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_temporal_nframes.errcheck = check_error

    lib.tof_processing_config_set_temporal_nframes.restype = None
    lib.tof_processing_config_set_temporal_nframes.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_processing_config_set_temporal_nframes.errcheck = check_error

    lib.tof_processing_config_get_gaussian_enabled.restype = ctypes.c_bool
    lib.tof_processing_config_get_gaussian_enabled.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_gaussian_enabled.errcheck = check_error

    lib.tof_processing_config_set_gaussian_enabled.restype = None
    lib.tof_processing_config_set_gaussian_enabled.argtypes = [ctypes.c_void_p, ctypes.c_bool, ctypes.c_void_p]
    lib.tof_processing_config_set_gaussian_enabled.errcheck = check_error

    lib.tof_processing_config_get_gaussian_size.restype = ctypes.c_size_t
    lib.tof_processing_config_get_gaussian_size.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_gaussian_size.errcheck = check_error

    lib.tof_processing_config_set_gaussian_size.restype = None
    lib.tof_processing_config_set_gaussian_size.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_processing_config_set_gaussian_size.errcheck = check_error

    lib.tof_processing_config_get_gaussian_sigma.restype = ctypes.c_double
    lib.tof_processing_config_get_gaussian_sigma.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_gaussian_sigma.errcheck = check_error

    lib.tof_processing_config_set_gaussian_sigma.restype = None
    lib.tof_processing_config_set_gaussian_sigma.argtypes = [ctypes.c_void_p, ctypes.c_double, ctypes.c_void_p]
    lib.tof_processing_config_set_gaussian_sigma.errcheck = check_error

    lib.tof_processing_config_get_median_enabled.restype = ctypes.c_bool
    lib.tof_processing_config_get_median_enabled.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_median_enabled.errcheck = check_error

    lib.tof_processing_config_set_median_enabled.restype = None
    lib.tof_processing_config_set_median_enabled.argtypes = [ctypes.c_void_p, ctypes.c_bool, ctypes.c_void_p]
    lib.tof_processing_config_set_median_enabled.errcheck = check_error

    lib.tof_processing_config_get_median_size.restype = ctypes.c_size_t
    lib.tof_processing_config_get_median_size.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_median_size.errcheck = check_error

    lib.tof_processing_config_set_median_size.restype = None
    lib.tof_processing_config_set_median_size.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_processing_config_set_median_size.errcheck = check_error

    lib.tof_processing_config_get_bilateral_enabled.restype = ctypes.c_bool
    lib.tof_processing_config_get_bilateral_enabled.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_bilateral_enabled.errcheck = check_error

    lib.tof_processing_config_set_bilateral_enabled.restype = None
    lib.tof_processing_config_set_bilateral_enabled.argtypes = [ctypes.c_void_p, ctypes.c_bool, ctypes.c_void_p]
    lib.tof_processing_config_set_bilateral_enabled.errcheck = check_error

    lib.tof_processing_config_get_bilateral_size.restype = ctypes.c_size_t
    lib.tof_processing_config_get_bilateral_size.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_bilateral_size.errcheck = check_error

    lib.tof_processing_config_set_bilateral_size.restype = None
    lib.tof_processing_config_set_bilateral_size.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_processing_config_set_bilateral_size.errcheck = check_error

    lib.tof_processing_config_get_bilateral_sigma.restype = ctypes.c_double
    lib.tof_processing_config_get_bilateral_sigma.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_bilateral_sigma.errcheck = check_error

    lib.tof_processing_config_set_bilateral_sigma.restype = None
    lib.tof_processing_config_set_bilateral_sigma.argtypes = [ctypes.c_void_p, ctypes.c_double, ctypes.c_void_p]
    lib.tof_processing_config_set_bilateral_sigma.errcheck = check_error

    lib.tof_processing_config_get_local_means_enabled.restype = ctypes.c_bool
    lib.tof_processing_config_get_local_means_enabled.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_local_means_enabled.errcheck = check_error

    lib.tof_processing_config_set_local_means_enabled.restype = None
    lib.tof_processing_config_set_local_means_enabled.argtypes = [ctypes.c_void_p, ctypes.c_bool, ctypes.c_void_p]
    lib.tof_processing_config_set_local_means_enabled.errcheck = check_error

    lib.tof_processing_config_get_local_means_size.restype = ctypes.c_size_t
    lib.tof_processing_config_get_local_means_size.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_local_means_size.errcheck = check_error

    lib.tof_processing_config_set_local_means_size.restype = None
    lib.tof_processing_config_set_local_means_size.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_processing_config_set_local_means_size.errcheck = check_error

    lib.tof_processing_config_get_local_means_sigma.restype = ctypes.c_double
    lib.tof_processing_config_get_local_means_sigma.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_local_means_sigma.errcheck = check_error

    lib.tof_processing_config_set_local_means_sigma.restype = None
    lib.tof_processing_config_set_local_means_sigma.argtypes = [ctypes.c_void_p, ctypes.c_double, ctypes.c_void_p]
    lib.tof_processing_config_set_local_means_sigma.errcheck = check_error

    lib.tof_processing_config_get_flying_enabled.restype = ctypes.c_bool
    lib.tof_processing_config_get_flying_enabled.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_flying_enabled.errcheck = check_error

    lib.tof_processing_config_set_flying_enabled.restype = None
    lib.tof_processing_config_set_flying_enabled.argtypes = [ctypes.c_void_p, ctypes.c_bool, ctypes.c_void_p]
    lib.tof_processing_config_set_flying_enabled.errcheck = check_error

    lib.tof_processing_config_get_flying_shape.restype = ctypes.c_int
    lib.tof_processing_config_get_flying_shape.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_flying_shape.errcheck = check_error

    lib.tof_processing_config_set_flying_shape.restype = None
    lib.tof_processing_config_set_flying_shape.argtypes = [ctypes.c_void_p, ctypes.c_int, ctypes.c_void_p]
    lib.tof_processing_config_set_flying_shape.errcheck = check_error

    lib.tof_processing_config_get_flying_distance.restype = ctypes.c_size_t
    lib.tof_processing_config_get_flying_distance.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_flying_distance.errcheck = check_error

    lib.tof_processing_config_set_flying_distance.restype = None
    lib.tof_processing_config_set_flying_distance.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_processing_config_set_flying_distance.errcheck = check_error

    lib.tof_processing_config_get_flying_edges.restype = ctypes.c_size_t
    lib.tof_processing_config_get_flying_edges.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_flying_edges.errcheck = check_error

    lib.tof_processing_config_set_flying_edges.restype = None
    lib.tof_processing_config_set_flying_edges.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_processing_config_set_flying_edges.errcheck = check_error

    lib.tof_processing_config_get_amp_threshold_enabled.restype = ctypes.c_bool
    lib.tof_processing_config_get_amp_threshold_enabled.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_amp_threshold_enabled.errcheck = check_error

    lib.tof_processing_config_set_amp_threshold_enabled.restype = None
    lib.tof_processing_config_set_amp_threshold_enabled.argtypes = [ctypes.c_void_p, ctypes.c_bool, ctypes.c_void_p]
    lib.tof_processing_config_set_amp_threshold_enabled.errcheck = check_error

    lib.tof_processing_config_get_amp_threshold_min.restype = ctypes.c_double
    lib.tof_processing_config_get_amp_threshold_min.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_amp_threshold_min.errcheck = check_error

    lib.tof_processing_config_set_amp_threshold_min.restype = None
    lib.tof_processing_config_set_amp_threshold_min.argtypes = [ctypes.c_void_p, ctypes.c_double, ctypes.c_void_p]
    lib.tof_processing_config_set_amp_threshold_min.errcheck = check_error

    lib.tof_processing_config_get_amp_threshold_max.restype = ctypes.c_double
    lib.tof_processing_config_get_amp_threshold_max.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_amp_threshold_max.errcheck = check_error

    lib.tof_processing_config_set_amp_threshold_max.restype = None
    lib.tof_processing_config_set_amp_threshold_max.argtypes = [ctypes.c_void_p, ctypes.c_double, ctypes.c_void_p]
    lib.tof_processing_config_set_amp_threshold_max.errcheck = check_error

    lib.tof_processing_config_get_dist_threshold_enabled.restype = ctypes.c_bool
    lib.tof_processing_config_get_dist_threshold_enabled.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_dist_threshold_enabled.errcheck = check_error

    lib.tof_processing_config_set_dist_threshold_enabled.restype = None
    lib.tof_processing_config_set_dist_threshold_enabled.argtypes = [ctypes.c_void_p, ctypes.c_bool, ctypes.c_void_p]
    lib.tof_processing_config_set_dist_threshold_enabled.errcheck = check_error

    lib.tof_processing_config_get_dist_threshold_min.restype = ctypes.c_double
    lib.tof_processing_config_get_dist_threshold_min.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_dist_threshold_min.errcheck = check_error

    lib.tof_processing_config_set_dist_threshold_min.restype = None
    lib.tof_processing_config_set_dist_threshold_min.argtypes = [ctypes.c_void_p, ctypes.c_double, ctypes.c_void_p]
    lib.tof_processing_config_set_dist_threshold_min.errcheck = check_error

    lib.tof_processing_config_get_dist_threshold_max.restype = ctypes.c_double
    lib.tof_processing_config_get_dist_threshold_max.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_dist_threshold_max.errcheck = check_error

    lib.tof_processing_config_set_dist_threshold_max.restype = None
    lib.tof_processing_config_set_dist_threshold_max.argtypes = [ctypes.c_void_p, ctypes.c_double, ctypes.c_void_p]
    lib.tof_processing_config_set_dist_threshold_max.errcheck = check_error

    lib.tof_processing_config_get_radial_scale.restype = ctypes.c_float
    lib.tof_processing_config_get_radial_scale.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_radial_scale.errcheck = check_error

    lib.tof_processing_config_set_radial_scale.restype = None
    lib.tof_processing_config_set_radial_scale.argtypes = [ctypes.c_void_p, ctypes.c_float, ctypes.c_void_p]
    lib.tof_processing_config_set_radial_scale.errcheck = check_error

    lib.tof_processing_config_get_radial_add.restype = ctypes.c_float
    lib.tof_processing_config_get_radial_add.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_radial_add.errcheck = check_error

    lib.tof_processing_config_set_radial_add.restype = None
    lib.tof_processing_config_set_radial_add.argtypes = [ctypes.c_void_p, ctypes.c_float, ctypes.c_void_p]
    lib.tof_processing_config_set_radial_add.errcheck = check_error

    lib.tof_processing_config_get_intensity_scale.restype = ctypes.c_float
    lib.tof_processing_config_get_intensity_scale.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_intensity_scale.errcheck = check_error

    lib.tof_processing_config_set_intensity_scale.restype = None
    lib.tof_processing_config_set_intensity_scale.argtypes = [ctypes.c_void_p, ctypes.c_float, ctypes.c_void_p]
    lib.tof_processing_config_set_intensity_scale.errcheck = check_error

    lib.tof_processing_config_get_intensity_add.restype = ctypes.c_float
    lib.tof_processing_config_get_intensity_add.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_intensity_add.errcheck = check_error

    lib.tof_processing_config_set_intensity_add.restype = None
    lib.tof_processing_config_set_intensity_add.argtypes = [ctypes.c_void_p, ctypes.c_float, ctypes.c_void_p]
    lib.tof_processing_config_set_intensity_add.errcheck = check_error

    lib.tof_processing_config_get_char_add.restype = ctypes.c_double
    lib.tof_processing_config_get_char_add.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_char_add.errcheck = check_error

    lib.tof_processing_config_set_char_add.restype = None
    lib.tof_processing_config_set_char_add.argtypes = [ctypes.c_void_p, ctypes.c_double, ctypes.c_void_p]
    lib.tof_processing_config_set_char_add.errcheck = check_error

    lib.tof_processing_config_get_char_mult.restype = ctypes.c_double
    lib.tof_processing_config_get_char_mult.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_char_mult.errcheck = check_error

    lib.tof_processing_config_set_char_mult.restype = None
    lib.tof_processing_config_set_char_mult.argtypes = [ctypes.c_void_p, ctypes.c_double, ctypes.c_void_p]
    lib.tof_processing_config_set_char_mult.errcheck = check_error

    lib.tof_processing_config_get_binning_enabled.restype = ctypes.c_bool
    lib.tof_processing_config_get_binning_enabled.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_binning_enabled.errcheck = check_error

    lib.tof_processing_config_set_binning_enabled.restype = None
    lib.tof_processing_config_set_binning_enabled.argtypes = [ctypes.c_void_p, ctypes.c_bool, ctypes.c_void_p]
    lib.tof_processing_config_set_binning_enabled.errcheck = check_error

    lib.tof_processing_config_get_binning_size.restype = ctypes.c_size_t
    lib.tof_processing_config_get_binning_size.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_binning_size.errcheck = check_error

    lib.tof_processing_config_set_binning_size.restype = None
    lib.tof_processing_config_set_binning_size.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_processing_config_set_binning_size.errcheck = check_error

    lib.tof_processing_config_get_binning_mode.restype = ctypes.c_int
    lib.tof_processing_config_get_binning_mode.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_binning_mode.errcheck = check_error

    lib.tof_processing_config_set_binning_mode.restype = None
    lib.tof_processing_config_set_binning_mode.argtypes = [ctypes.c_void_p, ctypes.c_int, ctypes.c_void_p]
    lib.tof_processing_config_set_binning_mode.errcheck = check_error

    lib.tof_processing_config_get_binning_sigma.restype = ctypes.c_float
    lib.tof_processing_config_get_binning_sigma.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_binning_sigma.errcheck = check_error

    lib.tof_processing_config_set_binning_sigma.restype = None
    lib.tof_processing_config_set_binning_sigma.argtypes = [ctypes.c_void_p, ctypes.c_float, ctypes.c_void_p]
    lib.tof_processing_config_set_binning_sigma.errcheck = check_error

    lib.tof_processing_config_get_xyz_dimension.restype = ctypes.c_int
    lib.tof_processing_config_get_xyz_dimension.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_xyz_dimension.errcheck = check_error

    lib.tof_processing_config_set_xyz_dimension.restype = None
    lib.tof_processing_config_set_xyz_dimension.argtypes = [ctypes.c_void_p, ctypes.c_int, ctypes.c_void_p]
    lib.tof_processing_config_set_xyz_dimension.errcheck = check_error

    lib.tof_processing_config_get_rigid_transformation_enabled.restype = ctypes.c_bool
    lib.tof_processing_config_get_rigid_transformation_enabled.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_rigid_transformation_enabled.errcheck = check_error

    lib.tof_processing_config_set_rigid_transformation_enabled.restype = None
    lib.tof_processing_config_set_rigid_transformation_enabled.argtypes = [ctypes.c_void_p, ctypes.c_bool, ctypes.c_void_p]
    lib.tof_processing_config_set_rigid_transformation_enabled.errcheck = check_error

    lib.tof_processing_config_get_rigid_transformation_matrix.restype = ctypes.POINTER(ctypes.c_float * 16)
    lib.tof_processing_config_get_rigid_transformation_matrix.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_processing_config_get_rigid_transformation_matrix.errcheck = check_error

    lib.tof_processing_config_set_rigid_transformation_matrix.restype = None
    lib.tof_processing_config_set_rigid_transformation_matrix.argtypes = [ctypes.c_void_p, (ctypes.c_float * 16), ctypes.c_void_p]
    lib.tof_processing_config_set_rigid_transformation_matrix.errcheck = check_error

    lib.tof_roi_delete.restype = None
    lib.tof_roi_delete.argtypes = [ctypes.c_void_p]

    lib.tof_roi_sensor_rows.restype = ctypes.c_int32
    lib.tof_roi_sensor_rows.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_roi_sensor_rows.errcheck = check_error

    lib.tof_roi_sensor_cols.restype = ctypes.c_int32
    lib.tof_roi_sensor_cols.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_roi_sensor_cols.errcheck = check_error

    lib.tof_roi_get_row_offset.restype = ctypes.c_int32
    lib.tof_roi_get_row_offset.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_roi_get_row_offset.errcheck = check_error

    lib.tof_roi_set_row_offset.restype = None
    lib.tof_roi_set_row_offset.argtypes = [ctypes.c_void_p, ctypes.c_int32, ctypes.c_void_p]
    lib.tof_roi_set_row_offset.errcheck = check_error

    lib.tof_roi_get_col_offset.restype = ctypes.c_int32
    lib.tof_roi_get_col_offset.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_roi_get_col_offset.errcheck = check_error

    lib.tof_roi_set_col_offset.restype = None
    lib.tof_roi_set_col_offset.argtypes = [ctypes.c_void_p, ctypes.c_int32, ctypes.c_void_p]
    lib.tof_roi_set_col_offset.errcheck = check_error

    lib.tof_roi_get_img_rows.restype = ctypes.c_int32
    lib.tof_roi_get_img_rows.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_roi_get_img_rows.errcheck = check_error

    lib.tof_roi_set_img_rows.restype = None
    lib.tof_roi_set_img_rows.argtypes = [ctypes.c_void_p, ctypes.c_int32, ctypes.c_void_p]
    lib.tof_roi_set_img_rows.errcheck = check_error

    lib.tof_roi_get_img_cols.restype = ctypes.c_int32
    lib.tof_roi_get_img_cols.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_roi_get_img_cols.errcheck = check_error

    lib.tof_roi_set_img_cols.restype = None
    lib.tof_roi_set_img_cols.argtypes = [ctypes.c_void_p, ctypes.c_int32, ctypes.c_void_p]
    lib.tof_roi_set_img_cols.errcheck = check_error

    lib.tof_camera_config_delete.restype = None
    lib.tof_camera_config_delete.argtypes = [ctypes.c_void_p]

    lib.tof_camera_config_new_from_disk.restype = ctypes.c_void_p
    lib.tof_camera_config_new_from_disk.argtypes = [ctypes.c_char_p, ctypes.c_void_p]
    lib.tof_camera_config_new_from_disk.errcheck = check_error

    lib.tof_camera_config_write.restype = None
    lib.tof_camera_config_write.argtypes = [ctypes.c_void_p, ctypes.c_char_p, ctypes.c_void_p]
    lib.tof_camera_config_write.errcheck = check_error

    lib.tof_camera_config_get_type.restype = ctypes.c_int
    lib.tof_camera_config_get_type.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_camera_config_get_type.errcheck = check_error

    lib.tof_camera_config_reset.restype = None
    lib.tof_camera_config_reset.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_camera_config_reset.errcheck = check_error

    lib.tof_camera_config_frame_size.restype = ctypes.c_size_t
    lib.tof_camera_config_frame_size.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_camera_config_frame_size.errcheck = check_error

    lib.tof_camera_config_add_frame.restype = None
    lib.tof_camera_config_add_frame.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_camera_config_add_frame.errcheck = check_error

    lib.tof_camera_config_default_processing.restype = ctypes.c_void_p
    lib.tof_camera_config_default_processing.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_camera_config_default_processing.errcheck = check_error

    lib.tof_camera_config_erase_frame.restype = None
    lib.tof_camera_config_erase_frame.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_camera_config_erase_frame.errcheck = check_error

    lib.tof_camera_config_get_phase_shifts.restype = ctypes.c_size_t
    lib.tof_camera_config_get_phase_shifts.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.POINTER(ctypes.c_float), ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_camera_config_get_phase_shifts.errcheck = check_error

    lib.tof_camera_config_set_phase_shifts.restype = None
    lib.tof_camera_config_set_phase_shifts.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.POINTER(ctypes.c_float), ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_camera_config_set_phase_shifts.errcheck = check_error

    lib.tof_camera_config_get_integration_time.restype = ctypes.c_size_t
    lib.tof_camera_config_get_integration_time.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.POINTER(ctypes.c_uint32), ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_camera_config_get_integration_time.errcheck = check_error

    lib.tof_camera_config_set_integration_time.restype = None
    lib.tof_camera_config_set_integration_time.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.POINTER(ctypes.c_uint32), ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_camera_config_set_integration_time.errcheck = check_error

    lib.tof_camera_config_get_sensor_mode.restype = ctypes.c_int
    lib.tof_camera_config_get_sensor_mode.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_camera_config_get_sensor_mode.errcheck = check_error

    lib.tof_camera_config_set_sensor_mode.restype = None
    lib.tof_camera_config_set_sensor_mode.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.c_int, ctypes.c_void_p]
    lib.tof_camera_config_set_sensor_mode.errcheck = check_error

    lib.tof_camera_config_get_modulation_frequency.restype = ctypes.c_float
    lib.tof_camera_config_get_modulation_frequency.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_camera_config_get_modulation_frequency.errcheck = check_error

    lib.tof_camera_config_set_modulation_frequency.restype = None
    lib.tof_camera_config_set_modulation_frequency.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.c_float, ctypes.c_void_p]
    lib.tof_camera_config_set_modulation_frequency.errcheck = check_error

    lib.tof_camera_config_get_duty_cycle.restype = ctypes.c_float
    lib.tof_camera_config_get_duty_cycle.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_camera_config_get_duty_cycle.errcheck = check_error

    lib.tof_camera_config_set_duty_cycle.restype = None
    lib.tof_camera_config_set_duty_cycle.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.c_float, ctypes.c_void_p]
    lib.tof_camera_config_set_duty_cycle.errcheck = check_error

    lib.tof_camera_config_get_roi.restype = ctypes.c_void_p
    lib.tof_camera_config_get_roi.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_camera_config_get_roi.errcheck = check_error

    lib.tof_camera_config_set_roi.restype = None
    lib.tof_camera_config_set_roi.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_camera_config_set_roi.errcheck = check_error

    lib.tof_camera_config_get_binning.restype = ctypes.c_uint8
    lib.tof_camera_config_get_binning.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_camera_config_get_binning.errcheck = check_error

    lib.tof_camera_config_set_binning.restype = None
    lib.tof_camera_config_set_binning.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.c_uint8, ctypes.c_void_p]
    lib.tof_camera_config_set_binning.errcheck = check_error

    lib.tof_camera_config_get_flip.restype = ctypes.c_bool
    lib.tof_camera_config_get_flip.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_camera_config_get_flip.errcheck = check_error

    lib.tof_camera_config_set_flip.restype = None
    lib.tof_camera_config_set_flip.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.c_bool, ctypes.c_void_p]
    lib.tof_camera_config_set_flip.errcheck = check_error

    lib.tof_camera_config_get_mirror.restype = ctypes.c_bool
    lib.tof_camera_config_get_mirror.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_camera_config_get_mirror.errcheck = check_error

    lib.tof_camera_config_set_mirror.restype = None
    lib.tof_camera_config_set_mirror.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.c_bool, ctypes.c_void_p]
    lib.tof_camera_config_set_mirror.errcheck = check_error

    lib.tof_camera_config_get_gain.restype = ctypes.c_float
    lib.tof_camera_config_get_gain.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_camera_config_get_gain.errcheck = check_error

    lib.tof_camera_config_set_gain.restype = None
    lib.tof_camera_config_set_gain.argtypes = [ctypes.c_void_p, ctypes.c_float, ctypes.c_void_p]
    lib.tof_camera_config_set_gain.errcheck = check_error

    lib.tof_camera_config_get_sync_mode.restype = ctypes.c_int32
    lib.tof_camera_config_get_sync_mode.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_camera_config_get_sync_mode.errcheck = check_error

    lib.tof_camera_config_set_sync_mode.restype = None
    lib.tof_camera_config_set_sync_mode.argtypes = [ctypes.c_void_p, ctypes.c_int32, ctypes.c_void_p]
    lib.tof_camera_config_set_sync_mode.errcheck = check_error

    lib.tof_camera_config_maximum_integration_time.restype = ctypes.c_size_t
    lib.tof_camera_config_maximum_integration_time.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.POINTER(ctypes.c_uint32), ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_camera_config_maximum_integration_time.errcheck = check_error

    lib.tof_camera_config_get_dac.restype = ctypes.c_size_t
    lib.tof_camera_config_get_dac.argtypes = [ctypes.c_void_p, ctypes.POINTER(ctypes.c_uint16), ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_camera_config_get_dac.errcheck = check_error

    lib.tof_camera_config_set_dac.restype = None
    lib.tof_camera_config_set_dac.argtypes = [ctypes.c_void_p, ctypes.POINTER(ctypes.c_uint16), ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_camera_config_set_dac.errcheck = check_error

    lib.tof_camera_config_get_mlx_mipi_speed.restype = ctypes.c_int32
    lib.tof_camera_config_get_mlx_mipi_speed.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_camera_config_get_mlx_mipi_speed.errcheck = check_error

    lib.tof_camera_config_set_mlx_mipi_speed.restype = None
    lib.tof_camera_config_set_mlx_mipi_speed.argtypes = [ctypes.c_void_p, ctypes.c_int32, ctypes.c_void_p]
    lib.tof_camera_config_set_mlx_mipi_speed.errcheck = check_error

    lib.tof_camera_config_get_mipi_speed.restype = ctypes.c_int32
    lib.tof_camera_config_get_mipi_speed.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_camera_config_get_mipi_speed.errcheck = check_error

    lib.tof_camera_config_set_mipi_speed.restype = None
    lib.tof_camera_config_set_mipi_speed.argtypes = [ctypes.c_void_p, ctypes.c_int32, ctypes.c_void_p]
    lib.tof_camera_config_set_mipi_speed.errcheck = check_error

    lib.tof_camera_config_get_mlx_preheat.restype = ctypes.c_uint32
    lib.tof_camera_config_get_mlx_preheat.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_camera_config_get_mlx_preheat.errcheck = check_error

    lib.tof_camera_config_set_mlx_preheat.restype = None
    lib.tof_camera_config_set_mlx_preheat.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.c_uint32, ctypes.c_void_p]
    lib.tof_camera_config_set_mlx_preheat.errcheck = check_error

    lib.tof_camera_config_get_mlx_preheat_enable.restype = ctypes.c_bool
    lib.tof_camera_config_get_mlx_preheat_enable.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_camera_config_get_mlx_preheat_enable.errcheck = check_error

    lib.tof_camera_config_set_mlx_preheat_enable.restype = None
    lib.tof_camera_config_set_mlx_preheat_enable.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.c_bool, ctypes.c_void_p]
    lib.tof_camera_config_set_mlx_preheat_enable.errcheck = check_error

    lib.tof_camera_config_set_opt_kea_nios_hex.restype = None
    lib.tof_camera_config_set_opt_kea_nios_hex.argtypes = [ctypes.c_void_p, ctypes.c_char_p, ctypes.c_void_p]
    lib.tof_camera_config_set_opt_kea_nios_hex.errcheck = check_error

    lib.tof_camera_config_get_opt_kea_sub_quad.restype = ctypes.POINTER(ctypes.c_int32 * 2)
    lib.tof_camera_config_get_opt_kea_sub_quad.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_camera_config_get_opt_kea_sub_quad.errcheck = check_error

    lib.tof_camera_config_set_opt_kea_sub_quad.restype = None
    lib.tof_camera_config_set_opt_kea_sub_quad.argtypes = [ctypes.c_void_p, (ctypes.c_int32 * 2), ctypes.c_void_p]
    lib.tof_camera_config_set_opt_kea_sub_quad.errcheck = check_error

    lib.tof_camera_config_get_processing.restype = ctypes.c_void_p
    lib.tof_camera_config_get_processing.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_camera_config_get_processing.errcheck = check_error

    lib.tof_camera_config_set_processing.restype = None
    lib.tof_camera_config_set_processing.argtypes = [ctypes.c_void_p, ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_camera_config_set_processing.errcheck = check_error

    lib.tof_camera_config_get_frame_time.restype = ctypes.c_uint32
    lib.tof_camera_config_get_frame_time.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_camera_config_get_frame_time.errcheck = check_error

    lib.tof_camera_config_set_frame_time.restype = None
    lib.tof_camera_config_set_frame_time.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.c_uint32, ctypes.c_void_p]
    lib.tof_camera_config_set_frame_time.errcheck = check_error

    lib.tof_camera_config_get_global_phase_offset.restype = ctypes.POINTER(ctypes.c_float * 2)
    lib.tof_camera_config_get_global_phase_offset.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_camera_config_get_global_phase_offset.errcheck = check_error

    lib.tof_camera_config_set_global_phase_offset.restype = None
    lib.tof_camera_config_set_global_phase_offset.argtypes = [ctypes.c_void_p, ctypes.c_size_t, (ctypes.c_float * 2), ctypes.c_void_p]
    lib.tof_camera_config_set_global_phase_offset.errcheck = check_error

    lib.tof_camera_config_get_illumination_mode.restype = ctypes.c_uint8
    lib.tof_camera_config_get_illumination_mode.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_camera_config_get_illumination_mode.errcheck = check_error

    lib.tof_camera_config_set_illumination_mode.restype = None
    lib.tof_camera_config_set_illumination_mode.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.c_uint8, ctypes.c_void_p]
    lib.tof_camera_config_set_illumination_mode.errcheck = check_error

    lib.tof_camera_config_get_image_offsets.restype = ctypes.c_size_t
    lib.tof_camera_config_get_image_offsets.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.POINTER(ctypes.c_float), ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_camera_config_get_image_offsets.errcheck = check_error

    lib.tof_camera_config_set_image_offsets.restype = None
    lib.tof_camera_config_set_image_offsets.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.POINTER(ctypes.c_float), ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_camera_config_set_image_offsets.errcheck = check_error

    lib.tof_camera_config_get_rgb_width.restype = ctypes.c_size_t
    lib.tof_camera_config_get_rgb_width.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_camera_config_get_rgb_width.errcheck = check_error

    lib.tof_camera_config_get_rgb_height.restype = ctypes.c_size_t
    lib.tof_camera_config_get_rgb_height.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_camera_config_get_rgb_height.errcheck = check_error

    lib.tof_camera_config_get_trigger_mode.restype = ctypes.c_int
    lib.tof_camera_config_get_trigger_mode.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_camera_config_get_trigger_mode.errcheck = check_error

    lib.tof_camera_config_set_trigger_mode.restype = None
    lib.tof_camera_config_set_trigger_mode.argtypes = [ctypes.c_void_p, ctypes.c_int, ctypes.c_void_p]
    lib.tof_camera_config_set_trigger_mode.errcheck = check_error

    lib.tof_camera_config_get_depth_fps.restype = ctypes.c_float
    lib.tof_camera_config_get_depth_fps.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_camera_config_get_depth_fps.errcheck = check_error

    lib.tof_point_2d_delete.restype = None
    lib.tof_point_2d_delete.argtypes = [ctypes.c_void_p]

    lib.tof_point_2d_row.restype = ctypes.c_int32
    lib.tof_point_2d_row.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_point_2d_row.errcheck = check_error

    lib.tof_point_2d_col.restype = ctypes.c_int32
    lib.tof_point_2d_col.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_point_2d_col.errcheck = check_error

    lib.tof_calibration_delete.restype = None
    lib.tof_calibration_delete.argtypes = [ctypes.c_void_p]

    lib.tof_calibration_new_from_disk.restype = ctypes.c_void_p
    lib.tof_calibration_new_from_disk.argtypes = [ctypes.c_char_p, ctypes.c_void_p]
    lib.tof_calibration_new_from_disk.errcheck = check_error

    lib.tof_calibration_write.restype = None
    lib.tof_calibration_write.argtypes = [ctypes.c_void_p, ctypes.c_char_p, ctypes.c_void_p]
    lib.tof_calibration_write.errcheck = check_error

    lib.tof_calibration_get_calibrated_frequencies.restype = ctypes.c_size_t
    lib.tof_calibration_get_calibrated_frequencies.argtypes = [ctypes.c_void_p, ctypes.POINTER(ctypes.c_float), ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_calibration_get_calibrated_frequencies.errcheck = check_error

    lib.tof_calibration_get_focal_length_x.restype = ctypes.c_double
    lib.tof_calibration_get_focal_length_x.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_calibration_get_focal_length_x.errcheck = check_error

    lib.tof_calibration_get_focal_length_y.restype = ctypes.c_double
    lib.tof_calibration_get_focal_length_y.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_calibration_get_focal_length_y.errcheck = check_error

    lib.tof_calibration_get_principal_point_x.restype = ctypes.c_double
    lib.tof_calibration_get_principal_point_x.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_calibration_get_principal_point_x.errcheck = check_error

    lib.tof_calibration_get_principal_point_y.restype = ctypes.c_double
    lib.tof_calibration_get_principal_point_y.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_calibration_get_principal_point_y.errcheck = check_error

    lib.tof_calibration_get_depth_camera_matrix.restype = ctypes.POINTER(ctypes.c_double * 9)
    lib.tof_calibration_get_depth_camera_matrix.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_calibration_get_depth_camera_matrix.errcheck = check_error

    lib.tof_calibration_get_depth_distortion_coefficients.restype = ctypes.POINTER(ctypes.c_double * 5)
    lib.tof_calibration_get_depth_distortion_coefficients.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_calibration_get_depth_distortion_coefficients.errcheck = check_error

    lib.tof_calibration_get_rgb_camera_matrix.restype = ctypes.POINTER(ctypes.c_double * 9)
    lib.tof_calibration_get_rgb_camera_matrix.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_calibration_get_rgb_camera_matrix.errcheck = check_error

    lib.tof_calibration_get_rgb_distortion_coefficients.restype = ctypes.POINTER(ctypes.c_double * 5)
    lib.tof_calibration_get_rgb_distortion_coefficients.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_calibration_get_rgb_distortion_coefficients.errcheck = check_error

    lib.tof_calibration_get_rotation_vector.restype = ctypes.POINTER(ctypes.c_double * 3)
    lib.tof_calibration_get_rotation_vector.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_calibration_get_rotation_vector.errcheck = check_error

    lib.tof_calibration_get_translation_vector.restype = ctypes.POINTER(ctypes.c_double * 3)
    lib.tof_calibration_get_translation_vector.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_calibration_get_translation_vector.errcheck = check_error

    lib.tof_transform_3d_to_depth_2d.restype = ctypes.c_void_p
    lib.tof_transform_3d_to_depth_2d.argtypes = [ctypes.c_float, ctypes.c_float, ctypes.c_float, ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_transform_3d_to_depth_2d.errcheck = check_error

    lib.tof_transform_3d_to_color_2d.restype = ctypes.c_void_p
    lib.tof_transform_3d_to_color_2d.argtypes = [ctypes.c_float, ctypes.c_float, ctypes.c_float, ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_transform_3d_to_color_2d.errcheck = check_error

    lib.tof_transform_color_2d_to_depth_2d.restype = ctypes.c_void_p
    lib.tof_transform_color_2d_to_depth_2d.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_transform_color_2d_to_depth_2d.errcheck = check_error

    lib.tof_camera_delete.restype = None
    lib.tof_camera_delete.argtypes = [ctypes.c_void_p]

    lib.tof_camera_start.restype = None
    lib.tof_camera_start.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_camera_start.errcheck = check_error

    lib.tof_camera_stop.restype = None
    lib.tof_camera_stop.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_camera_stop.errcheck = check_error

    lib.tof_camera_is_streaming.restype = ctypes.c_bool
    lib.tof_camera_is_streaming.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_camera_is_streaming.errcheck = check_error

    lib.tof_camera_is_connected.restype = ctypes.c_bool
    lib.tof_camera_is_connected.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_camera_is_connected.errcheck = check_error

    lib.tof_camera_get_stream_list.restype = ctypes.c_size_t
    lib.tof_camera_get_stream_list.argtypes = [ctypes.c_void_p, ctypes.POINTER(ctypes.c_void_p), ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_camera_get_stream_list.errcheck = check_error

    lib.tof_camera_set_stream_list.restype = None
    lib.tof_camera_set_stream_list.argtypes = [ctypes.c_void_p, ctypes.POINTER(ctypes.c_void_p), ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_camera_set_stream_list.errcheck = check_error

    lib.tof_camera_is_stream_list_set.restype = ctypes.c_bool
    lib.tof_camera_is_stream_list_set.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_camera_is_stream_list_set.errcheck = check_error

    lib.tof_camera_get_set_stream_list.restype = ctypes.c_size_t
    lib.tof_camera_get_set_stream_list.argtypes = [ctypes.c_void_p, ctypes.POINTER(ctypes.c_void_p), ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_camera_get_set_stream_list.errcheck = check_error

    lib.tof_camera_get_process_config.restype = ctypes.c_void_p
    lib.tof_camera_get_process_config.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_camera_get_process_config.errcheck = check_error

    lib.tof_camera_set_process_config.restype = None
    lib.tof_camera_set_process_config.argtypes = [ctypes.c_void_p, ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_camera_set_process_config.errcheck = check_error

    lib.tof_camera_has_frames.restype = ctypes.c_bool
    lib.tof_camera_has_frames.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_camera_has_frames.errcheck = check_error

    lib.tof_camera_get_frames.restype = ctypes.c_size_t
    lib.tof_camera_get_frames.argtypes = [ctypes.c_void_p, ctypes.POINTER(ctypes.c_void_p), ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_camera_get_frames.errcheck = check_error

    lib.tof_camera_clear_buffer.restype = None
    lib.tof_camera_clear_buffer.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_camera_clear_buffer.errcheck = check_error

    lib.tof_camera_get_buffer_size.restype = ctypes.c_size_t
    lib.tof_camera_get_buffer_size.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_camera_get_buffer_size.errcheck = check_error

    lib.tof_camera_set_buffer_size.restype = None
    lib.tof_camera_set_buffer_size.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_camera_set_buffer_size.errcheck = check_error

    lib.tof_camera_get_camera_config.restype = ctypes.c_void_p
    lib.tof_camera_get_camera_config.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_camera_get_camera_config.errcheck = check_error

    lib.tof_camera_get_serial.restype = ctypes.c_char_p
    lib.tof_camera_get_serial.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_camera_get_serial.errcheck = check_error

    lib.tof_camera_get_calibration.restype = ctypes.c_void_p
    lib.tof_camera_get_calibration.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_camera_get_calibration.errcheck = check_error

    lib.tof_camera_get_user_pointer_capacity.restype = ctypes.c_size_t
    lib.tof_camera_get_user_pointer_capacity.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_camera_get_user_pointer_capacity.errcheck = check_error

    lib.tof_camera_set_user_pointer_capacity.restype = None
    lib.tof_camera_set_user_pointer_capacity.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_camera_set_user_pointer_capacity.errcheck = check_error

    lib.tof_camera_clear_user_pointers.restype = None
    lib.tof_camera_clear_user_pointers.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_camera_clear_user_pointers.errcheck = check_error

    lib.tof_select_streams.restype = ctypes.c_size_t
    lib.tof_select_streams.argtypes = [ctypes.c_void_p, ctypes.POINTER(ctypes.c_int), ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_select_streams.errcheck = check_error

    lib.tof_select_streams_mod_freq.restype = ctypes.c_size_t
    lib.tof_select_streams_mod_freq.argtypes = [ctypes.c_void_p, ctypes.POINTER(ctypes.c_int), ctypes.c_size_t, ctypes.c_float, ctypes.c_void_p]
    lib.tof_select_streams_mod_freq.errcheck = check_error

    lib.tof_kea_camera_delete.restype = None
    lib.tof_kea_camera_delete.argtypes = [ctypes.c_void_p]

    lib.tof_kea_camera_new.restype = ctypes.c_void_p
    lib.tof_kea_camera_new.argtypes = [ctypes.c_void_p, ctypes.c_char_p, ctypes.c_void_p]
    lib.tof_kea_camera_new.errcheck = check_error

    lib.tof_kea_camera_new_simple.restype = ctypes.c_void_p
    lib.tof_kea_camera_new_simple.argtypes = [ctypes.c_char_p, ctypes.c_void_p]
    lib.tof_kea_camera_new_simple.errcheck = check_error

    lib.tof_kea_camera_new_both_configs.restype = ctypes.c_void_p
    lib.tof_kea_camera_new_both_configs.argtypes = [ctypes.c_void_p, ctypes.c_char_p, ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_kea_camera_new_both_configs.errcheck = check_error

    lib.tof_kea_camera_on_camera_processing_capable.restype = ctypes.c_bool
    lib.tof_kea_camera_on_camera_processing_capable.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_kea_camera_on_camera_processing_capable.errcheck = check_error

    lib.tof_kea_camera_get_on_camera_processing.restype = ctypes.c_bool
    lib.tof_kea_camera_get_on_camera_processing.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_kea_camera_get_on_camera_processing.errcheck = check_error

    lib.tof_kea_camera_set_on_camera_processing.restype = None
    lib.tof_kea_camera_set_on_camera_processing.argtypes = [ctypes.c_void_p, ctypes.c_bool, ctypes.c_void_p]
    lib.tof_kea_camera_set_on_camera_processing.errcheck = check_error

    lib.tof_kea_camera_get_delay.restype = ctypes.c_uint32
    lib.tof_kea_camera_get_delay.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_kea_camera_get_delay.errcheck = check_error

    lib.tof_kea_camera_set_delay.restype = None
    lib.tof_kea_camera_set_delay.argtypes = [ctypes.c_void_p, ctypes.c_uint32, ctypes.c_void_p]
    lib.tof_kea_camera_set_delay.errcheck = check_error

    lib.tof_kea_camera_get_packet_size.restype = ctypes.c_uint16
    lib.tof_kea_camera_get_packet_size.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_kea_camera_get_packet_size.errcheck = check_error

    lib.tof_kea_camera_set_packet_size.restype = None
    lib.tof_kea_camera_set_packet_size.argtypes = [ctypes.c_void_p, ctypes.c_uint16, ctypes.c_void_p]
    lib.tof_kea_camera_set_packet_size.errcheck = check_error

    lib.tof_kea_camera_set_camera_config.restype = None
    lib.tof_kea_camera_set_camera_config.argtypes = [ctypes.c_void_p, ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_kea_camera_set_camera_config.errcheck = check_error

    lib.tof_kea_camera_set_configurations.restype = None
    lib.tof_kea_camera_set_configurations.argtypes = [ctypes.c_void_p, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_kea_camera_set_configurations.errcheck = check_error

    lib.tof_kea_camera_version.restype = ctypes.c_char_p
    lib.tof_kea_camera_version.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_kea_camera_version.errcheck = check_error

    lib.tof_kea_camera_software_trigger_capable.restype = ctypes.c_bool
    lib.tof_kea_camera_software_trigger_capable.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_kea_camera_software_trigger_capable.errcheck = check_error

    lib.tof_kea_camera_software_trigger.restype = None
    lib.tof_kea_camera_software_trigger.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_kea_camera_software_trigger.errcheck = check_error

    lib.tof_kea_camera_remote_update_capable.restype = ctypes.c_bool
    lib.tof_kea_camera_remote_update_capable.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_kea_camera_remote_update_capable.errcheck = check_error

    lib.tof_kea_camera_remote_update.restype = None
    lib.tof_kea_camera_remote_update.argtypes = [ctypes.c_void_p, ctypes.c_char_p, ctypes.c_void_p]
    lib.tof_kea_camera_remote_update.errcheck = check_error

    lib.tof_discovered_kea_delete.restype = None
    lib.tof_discovered_kea_delete.argtypes = [ctypes.c_void_p]

    lib.tof_discovered_kea_serial.restype = ctypes.c_char_p
    lib.tof_discovered_kea_serial.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_discovered_kea_serial.errcheck = check_error

    lib.tof_discovered_kea_info.restype = ctypes.c_char_p
    lib.tof_discovered_kea_info.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_discovered_kea_info.errcheck = check_error

    lib.tof_discover_kea_cameras.restype = ctypes.c_size_t
    lib.tof_discover_kea_cameras.argtypes = [ctypes.POINTER(ctypes.c_void_p), ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_discover_kea_cameras.errcheck = check_error

    lib.tof_create_kea_camera_gige.restype = ctypes.c_void_p
    lib.tof_create_kea_camera_gige.argtypes = [ctypes.c_void_p, ctypes.c_char_p, ctypes.c_uint16, ctypes.c_void_p]
    lib.tof_create_kea_camera_gige.errcheck = check_error

    lib.tof_crash_report_delete.restype = None
    lib.tof_crash_report_delete.argtypes = [ctypes.c_void_p]

    lib.tof_crash_report_new.restype = ctypes.c_void_p
    lib.tof_crash_report_new.argtypes = [ctypes.c_char_p, ctypes.c_char_p, ctypes.c_void_p]
    lib.tof_crash_report_new.errcheck = check_error

    lib.tof_crash_report_get_description.restype = ctypes.c_char_p
    lib.tof_crash_report_get_description.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_crash_report_get_description.errcheck = check_error

    lib.tof_crash_report_set_description.restype = None
    lib.tof_crash_report_set_description.argtypes = [ctypes.c_void_p, ctypes.c_char_p, ctypes.c_void_p]
    lib.tof_crash_report_set_description.errcheck = check_error

    lib.tof_crash_report_get_report.restype = ctypes.c_char_p
    lib.tof_crash_report_get_report.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_crash_report_get_report.errcheck = check_error

    lib.tof_crash_report_save.restype = None
    lib.tof_crash_report_save.argtypes = [ctypes.c_void_p, ctypes.c_char_p, ctypes.c_void_p]
    lib.tof_crash_report_save.errcheck = check_error

    lib.tof_get_version.restype = ctypes.c_char_p
    lib.tof_get_version.argtypes = [ctypes.c_void_p]
    lib.tof_get_version.errcheck = check_error

    lib.tof_log_to_console.restype = None
    lib.tof_log_to_console.argtypes = [ctypes.c_void_p]
    lib.tof_log_to_console.errcheck = check_error

    lib.tof_log_to_file.restype = None
    lib.tof_log_to_file.argtypes = [ctypes.c_char_p, ctypes.c_void_p]
    lib.tof_log_to_file.errcheck = check_error

    lib.tof_log_drop.restype = None
    lib.tof_log_drop.argtypes = [ctypes.c_void_p]
    lib.tof_log_drop.errcheck = check_error

    lib.tof_csf_camera_delete.restype = None
    lib.tof_csf_camera_delete.argtypes = [ctypes.c_void_p]

    lib.tof_csf_camera_new.restype = ctypes.c_void_p
    lib.tof_csf_camera_new.argtypes = [ctypes.c_void_p, ctypes.c_char_p, ctypes.c_void_p]
    lib.tof_csf_camera_new.errcheck = check_error

    lib.tof_csf_camera_new_simple.restype = ctypes.c_void_p
    lib.tof_csf_camera_new_simple.argtypes = [ctypes.c_char_p, ctypes.c_void_p]
    lib.tof_csf_camera_new_simple.errcheck = check_error

    lib.tof_csf_camera_get_frames_at.restype = ctypes.c_size_t
    lib.tof_csf_camera_get_frames_at.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.POINTER(ctypes.c_void_p), ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_csf_camera_get_frames_at.errcheck = check_error

    lib.tof_csf_camera_get_current_frame.restype = ctypes.c_size_t
    lib.tof_csf_camera_get_current_frame.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_csf_camera_get_current_frame.errcheck = check_error

    lib.tof_csf_camera_get_frame_number.restype = ctypes.c_size_t
    lib.tof_csf_camera_get_frame_number.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_csf_camera_get_frame_number.errcheck = check_error

    lib.tof_csf_camera_get_fps.restype = ctypes.c_size_t
    lib.tof_csf_camera_get_fps.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_csf_camera_get_fps.errcheck = check_error

    lib.tof_csf_camera_set_fps.restype = None
    lib.tof_csf_camera_set_fps.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_csf_camera_set_fps.errcheck = check_error

    lib.tof_discovery_message_delete.restype = None
    lib.tof_discovery_message_delete.argtypes = [ctypes.c_void_p]

    lib.tof_discovery_message_ip.restype = ctypes.c_char_p
    lib.tof_discovery_message_ip.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_discovery_message_ip.errcheck = check_error

    lib.tof_discovery_message_serial.restype = ctypes.c_char_p
    lib.tof_discovery_message_serial.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_discovery_message_serial.errcheck = check_error

    lib.tof_persistent_ip_delete.restype = None
    lib.tof_persistent_ip_delete.argtypes = [ctypes.c_void_p]

    lib.tof_persistent_ip_new.restype = ctypes.c_void_p
    lib.tof_persistent_ip_new.argtypes = [ctypes.c_char_p, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_bool, ctypes.c_void_p]
    lib.tof_persistent_ip_new.errcheck = check_error

    lib.tof_persistent_ip_get_ip.restype = ctypes.c_char_p
    lib.tof_persistent_ip_get_ip.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_persistent_ip_get_ip.errcheck = check_error

    lib.tof_persistent_ip_set_ip.restype = None
    lib.tof_persistent_ip_set_ip.argtypes = [ctypes.c_void_p, ctypes.c_char_p, ctypes.c_void_p]
    lib.tof_persistent_ip_set_ip.errcheck = check_error

    lib.tof_persistent_ip_get_netmask.restype = ctypes.c_char_p
    lib.tof_persistent_ip_get_netmask.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_persistent_ip_get_netmask.errcheck = check_error

    lib.tof_persistent_ip_set_netmask.restype = None
    lib.tof_persistent_ip_set_netmask.argtypes = [ctypes.c_void_p, ctypes.c_char_p, ctypes.c_void_p]
    lib.tof_persistent_ip_set_netmask.errcheck = check_error

    lib.tof_persistent_ip_get_gateway.restype = ctypes.c_char_p
    lib.tof_persistent_ip_get_gateway.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_persistent_ip_get_gateway.errcheck = check_error

    lib.tof_persistent_ip_set_gateway.restype = None
    lib.tof_persistent_ip_set_gateway.argtypes = [ctypes.c_void_p, ctypes.c_char_p, ctypes.c_void_p]
    lib.tof_persistent_ip_set_gateway.errcheck = check_error

    lib.tof_persistent_ip_get_enabled.restype = ctypes.c_bool
    lib.tof_persistent_ip_get_enabled.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_persistent_ip_get_enabled.errcheck = check_error

    lib.tof_persistent_ip_set_enabled.restype = None
    lib.tof_persistent_ip_set_enabled.argtypes = [ctypes.c_void_p, ctypes.c_bool, ctypes.c_void_p]
    lib.tof_persistent_ip_set_enabled.errcheck = check_error

    lib.tof_gige_interface_delete.restype = None
    lib.tof_gige_interface_delete.argtypes = [ctypes.c_void_p]

    lib.tof_gige_interface_new.restype = ctypes.c_void_p
    lib.tof_gige_interface_new.argtypes = [ctypes.c_uint16, ctypes.c_void_p]
    lib.tof_gige_interface_new.errcheck = check_error

    lib.tof_gige_interface_discover.restype = ctypes.c_size_t
    lib.tof_gige_interface_discover.argtypes = [ctypes.c_void_p, ctypes.POINTER(ctypes.c_void_p), ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_gige_interface_discover.errcheck = check_error

    lib.tof_gige_interface_discover_one.restype = ctypes.c_void_p
    lib.tof_gige_interface_discover_one.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_gige_interface_discover_one.errcheck = check_error

    lib.tof_gige_interface_find.restype = ctypes.c_void_p
    lib.tof_gige_interface_find.argtypes = [ctypes.c_void_p, ctypes.c_char_p, ctypes.c_void_p]
    lib.tof_gige_interface_find.errcheck = check_error

    lib.tof_gige_interface_connect.restype = None
    lib.tof_gige_interface_connect.argtypes = [ctypes.c_void_p, ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_gige_interface_connect.errcheck = check_error

    lib.tof_gige_interface_disconnect.restype = None
    lib.tof_gige_interface_disconnect.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_gige_interface_disconnect.errcheck = check_error

    lib.tof_gige_interface_is_connected.restype = ctypes.c_bool
    lib.tof_gige_interface_is_connected.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_gige_interface_is_connected.errcheck = check_error

    lib.tof_gige_interface_get_stream_packet_size.restype = ctypes.c_uint16
    lib.tof_gige_interface_get_stream_packet_size.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_gige_interface_get_stream_packet_size.errcheck = check_error

    lib.tof_gige_interface_set_stream_packet_size.restype = None
    lib.tof_gige_interface_set_stream_packet_size.argtypes = [ctypes.c_void_p, ctypes.c_uint16, ctypes.c_void_p]
    lib.tof_gige_interface_set_stream_packet_size.errcheck = check_error

    lib.tof_gige_interface_test_stream_packet_size.restype = ctypes.c_bool
    lib.tof_gige_interface_test_stream_packet_size.argtypes = [ctypes.c_void_p, ctypes.c_uint16, ctypes.c_void_p]
    lib.tof_gige_interface_test_stream_packet_size.errcheck = check_error

    lib.tof_gige_interface_get_delay.restype = ctypes.c_uint32
    lib.tof_gige_interface_get_delay.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_gige_interface_get_delay.errcheck = check_error

    lib.tof_gige_interface_set_delay.restype = None
    lib.tof_gige_interface_set_delay.argtypes = [ctypes.c_void_p, ctypes.c_uint32, ctypes.c_void_p]
    lib.tof_gige_interface_set_delay.errcheck = check_error

    lib.tof_gige_interface_download_configuration.restype = ctypes.c_void_p
    lib.tof_gige_interface_download_configuration.argtypes = [ctypes.c_void_p, ctypes.c_uint16, ctypes.c_void_p]
    lib.tof_gige_interface_download_configuration.errcheck = check_error

    lib.tof_gige_interface_download_calibration.restype = ctypes.c_void_p
    lib.tof_gige_interface_download_calibration.argtypes = [ctypes.c_void_p, ctypes.c_uint16, ctypes.c_void_p]
    lib.tof_gige_interface_download_calibration.errcheck = check_error

    lib.tof_gige_interface_upload_configuration.restype = None
    lib.tof_gige_interface_upload_configuration.argtypes = [ctypes.c_void_p, ctypes.c_void_p, ctypes.c_uint16, ctypes.c_void_p]
    lib.tof_gige_interface_upload_configuration.errcheck = check_error

    lib.tof_gige_interface_depth_stream_capable.restype = ctypes.c_bool
    lib.tof_gige_interface_depth_stream_capable.argtypes = [ctypes.c_void_p, ctypes.c_int, ctypes.c_void_p]
    lib.tof_gige_interface_depth_stream_capable.errcheck = check_error

    lib.tof_gige_interface_start_depth_stream.restype = None
    lib.tof_gige_interface_start_depth_stream.argtypes = [ctypes.c_void_p, ctypes.c_int, ctypes.c_uint16, ctypes.c_void_p]
    lib.tof_gige_interface_start_depth_stream.errcheck = check_error

    lib.tof_gige_interface_stop_depth_stream.restype = None
    lib.tof_gige_interface_stop_depth_stream.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_gige_interface_stop_depth_stream.errcheck = check_error

    lib.tof_gige_interface_has_depth_data.restype = ctypes.c_bool
    lib.tof_gige_interface_has_depth_data.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_gige_interface_has_depth_data.errcheck = check_error

    lib.tof_gige_interface_get_depth_data.restype = ctypes.c_void_p
    lib.tof_gige_interface_get_depth_data.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_gige_interface_get_depth_data.errcheck = check_error

    lib.tof_gige_interface_image_stream_capable.restype = ctypes.c_bool
    lib.tof_gige_interface_image_stream_capable.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_gige_interface_image_stream_capable.errcheck = check_error

    lib.tof_gige_interface_start_image_stream.restype = None
    lib.tof_gige_interface_start_image_stream.argtypes = [ctypes.c_void_p, ctypes.c_uint16, ctypes.c_void_p]
    lib.tof_gige_interface_start_image_stream.errcheck = check_error

    lib.tof_gige_interface_stop_image_stream.restype = None
    lib.tof_gige_interface_stop_image_stream.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_gige_interface_stop_image_stream.errcheck = check_error

    lib.tof_gige_interface_has_image_data.restype = ctypes.c_bool
    lib.tof_gige_interface_has_image_data.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_gige_interface_has_image_data.errcheck = check_error

    lib.tof_gige_interface_get_image_data.restype = ctypes.c_void_p
    lib.tof_gige_interface_get_image_data.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_gige_interface_get_image_data.errcheck = check_error

    lib.tof_gige_interface_persistent_ip_capable.restype = ctypes.c_bool
    lib.tof_gige_interface_persistent_ip_capable.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_gige_interface_persistent_ip_capable.errcheck = check_error

    lib.tof_gige_interface_get_persistent_ip.restype = ctypes.c_void_p
    lib.tof_gige_interface_get_persistent_ip.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_gige_interface_get_persistent_ip.errcheck = check_error

    lib.tof_gige_interface_set_persistent_ip.restype = None
    lib.tof_gige_interface_set_persistent_ip.argtypes = [ctypes.c_void_p, ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_gige_interface_set_persistent_ip.errcheck = check_error

    lib.tof_gige_interface_get_user_pointer_capacity.restype = ctypes.c_size_t
    lib.tof_gige_interface_get_user_pointer_capacity.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_gige_interface_get_user_pointer_capacity.errcheck = check_error

    lib.tof_gige_interface_set_user_pointer_capacity.restype = None
    lib.tof_gige_interface_set_user_pointer_capacity.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_gige_interface_set_user_pointer_capacity.errcheck = check_error

    lib.tof_gige_interface_version.restype = ctypes.c_char_p
    lib.tof_gige_interface_version.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_gige_interface_version.errcheck = check_error

    lib.tof_gige_interface_software_trigger_capable.restype = ctypes.c_bool
    lib.tof_gige_interface_software_trigger_capable.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_gige_interface_software_trigger_capable.errcheck = check_error

    lib.tof_gige_interface_software_trigger.restype = None
    lib.tof_gige_interface_software_trigger.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_gige_interface_software_trigger.errcheck = check_error

    lib.tof_usb_device_delete.restype = None
    lib.tof_usb_device_delete.argtypes = [ctypes.c_void_p]

    lib.tof_usb_device_serial.restype = ctypes.c_char_p
    lib.tof_usb_device_serial.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_usb_device_serial.errcheck = check_error

    lib.tof_usb_interface_delete.restype = None
    lib.tof_usb_interface_delete.argtypes = [ctypes.c_void_p]

    lib.tof_usb_interface_new.restype = ctypes.c_void_p
    lib.tof_usb_interface_new.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_usb_interface_new.errcheck = check_error

    lib.tof_usb_interface_is_connected.restype = ctypes.c_bool
    lib.tof_usb_interface_is_connected.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_usb_interface_is_connected.errcheck = check_error

    lib.tof_usb_interface_test_stream_speed.restype = ctypes.c_double
    lib.tof_usb_interface_test_stream_speed.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_usb_interface_test_stream_speed.errcheck = check_error

    lib.tof_usb_interface_download_configuration.restype = ctypes.c_void_p
    lib.tof_usb_interface_download_configuration.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_usb_interface_download_configuration.errcheck = check_error

    lib.tof_usb_interface_download_calibration.restype = ctypes.c_void_p
    lib.tof_usb_interface_download_calibration.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_usb_interface_download_calibration.errcheck = check_error

    lib.tof_usb_interface_upload_configuration.restype = None
    lib.tof_usb_interface_upload_configuration.argtypes = [ctypes.c_void_p, ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_usb_interface_upload_configuration.errcheck = check_error

    lib.tof_usb_interface_depth_stream_capable.restype = ctypes.c_bool
    lib.tof_usb_interface_depth_stream_capable.argtypes = [ctypes.c_void_p, ctypes.c_int, ctypes.c_void_p]
    lib.tof_usb_interface_depth_stream_capable.errcheck = check_error

    lib.tof_usb_interface_start_depth_stream.restype = None
    lib.tof_usb_interface_start_depth_stream.argtypes = [ctypes.c_void_p, ctypes.c_int, ctypes.c_void_p]
    lib.tof_usb_interface_start_depth_stream.errcheck = check_error

    lib.tof_usb_interface_stop_depth_stream.restype = None
    lib.tof_usb_interface_stop_depth_stream.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_usb_interface_stop_depth_stream.errcheck = check_error

    lib.tof_usb_interface_has_depth_data.restype = ctypes.c_bool
    lib.tof_usb_interface_has_depth_data.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_usb_interface_has_depth_data.errcheck = check_error

    lib.tof_usb_interface_get_depth_data.restype = ctypes.c_void_p
    lib.tof_usb_interface_get_depth_data.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_usb_interface_get_depth_data.errcheck = check_error

    lib.tof_usb_interface_image_stream_capable.restype = ctypes.c_bool
    lib.tof_usb_interface_image_stream_capable.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_usb_interface_image_stream_capable.errcheck = check_error

    lib.tof_usb_interface_start_image_stream.restype = None
    lib.tof_usb_interface_start_image_stream.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_usb_interface_start_image_stream.errcheck = check_error

    lib.tof_usb_interface_stop_image_stream.restype = None
    lib.tof_usb_interface_stop_image_stream.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_usb_interface_stop_image_stream.errcheck = check_error

    lib.tof_usb_interface_has_image_data.restype = ctypes.c_bool
    lib.tof_usb_interface_has_image_data.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_usb_interface_has_image_data.errcheck = check_error

    lib.tof_usb_interface_get_image_data.restype = ctypes.c_void_p
    lib.tof_usb_interface_get_image_data.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_usb_interface_get_image_data.errcheck = check_error

    lib.tof_usb_interface_get_user_pointer_capacity.restype = ctypes.c_size_t
    lib.tof_usb_interface_get_user_pointer_capacity.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_usb_interface_get_user_pointer_capacity.errcheck = check_error

    lib.tof_usb_interface_set_user_pointer_capacity.restype = None
    lib.tof_usb_interface_set_user_pointer_capacity.argtypes = [ctypes.c_void_p, ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_usb_interface_set_user_pointer_capacity.errcheck = check_error

    lib.tof_usb_interface_version.restype = ctypes.c_char_p
    lib.tof_usb_interface_version.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_usb_interface_version.errcheck = check_error

    lib.tof_usb_interface_software_trigger_capable.restype = ctypes.c_bool
    lib.tof_usb_interface_software_trigger_capable.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_usb_interface_software_trigger_capable.errcheck = check_error

    lib.tof_usb_interface_software_trigger.restype = None
    lib.tof_usb_interface_software_trigger.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
    lib.tof_usb_interface_software_trigger.errcheck = check_error

    lib.tof_usb_device_discover.restype = ctypes.c_size_t
    lib.tof_usb_device_discover.argtypes = [ctypes.POINTER(ctypes.c_void_p), ctypes.c_size_t, ctypes.c_void_p]
    lib.tof_usb_device_discover.errcheck = check_error

    lib.tof_usb_device_discover_one.restype = ctypes.c_void_p
    lib.tof_usb_device_discover_one.argtypes = [ctypes.c_void_p]
    lib.tof_usb_device_discover_one.errcheck = check_error

    lib.tof_usb_device_find.restype = ctypes.c_void_p
    lib.tof_usb_device_find.argtypes = [ctypes.c_char_p, ctypes.c_void_p]
    lib.tof_usb_device_find.errcheck = check_error


lib = find_library()
setup_library(lib)
